@@ -2,7 +2,7 @@ package AnyEvent::Twitter::Stream;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 use AnyEvent;
 use AnyEvent::HTTP;
@@ -59,7 +59,7 @@ sub new {
         $decode_json = 1;
     }
 
-    my ($zlib, my $_zstatus);
+    my ($zlib, $_zstatus);
     if (delete $args{use_compression}){
         ($zlib, $_zstatus)  = Compress::Raw::Zlib::Inflate->new(
             -LimitOutput => 1,
@@ -257,6 +257,8 @@ AnyEvent::Twitter::Stream - Receive Twitter streaming API in an event loop
 =head1 SYNOPSIS
 
   use AnyEvent::Twitter::Stream;
+  
+  my $done = AE::cv;
 
   # receive updates from @following_ids
   my $listener = AnyEvent::Twitter::Stream->new(
@@ -297,6 +299,8 @@ AnyEvent::Twitter::Stream - Receive Twitter streaming API in an event loop
       track           => "...",
       on_tweet        => sub { ... },
   );
+  
+  $done->recv;
 
 =head1 DESCRIPTION
 
@@ -318,15 +322,11 @@ These arguments are used for basic authentication.
 
 =item B<consumer_key> B<consumer_secret> B<token> B<token_secret>
 
-If you want to use the OAuth authentication mechanism, you need to set use arguments
-
-=item B<consumer_key> B<consumer_secret> B<token> B<token_secret>
-
 If you want to use the OAuth authentication mechanism, you need to set these arguments
 
 =item B<method>
 
-The name of the method you want to use on the stream. Currently, anyone of :
+The name of the method you want to use on the stream. Currently, any one of :
 
 =over 2
 
@@ -364,7 +364,8 @@ Callback to execute when a stream is connected.
 
 =item B<on_tweet>
 
-Callback to execute when a new tweet is received.
+Callback to execute when a new tweet is received. The argument is the tweet, a hashref documented at
+L<https://dev.twitter.com/docs/api/1/get/statuses/show/%3Aid>.
 
 =item B<on_error>
 
